==> gcc-java-3.2.3.tar.bz2: gcc-3.2.3/libjava/java/security/Principal.java <==
/* Principal.java -- A security entity
   Copyright (C) 1998 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package java.security;

/**
   * This interface models an entity (such as a user or a certificate authority)
   * for the purposes of applying the Java security model.
   *
   * @version 0.0
   *
   * @author Aaron M. Renn (arenn@urbanophile.com)
 */
public interface Principal
{
  /**
   * This method returns a <code>String</code> that names this 
   * <code>Principal</code>.
   *
   * @return The name of this <code>Principal</code>.
   */
  public abstract String getName();

  /**
   * This method tests another <code>Principal</code> object for equality
   * with this one.
   * 
   * @param obj The <code>Object</code> (which is a <code>Principal</code>) to test for equality against.
   *
   * @return <code>true</code> if the specified <code>Principal</code> is equal to this one, <code>false</code> otherwise.
   */
  public abstract boolean equals(Object obj);

  /**
   * This method returns a hash code value for this <code>Principal</code>.
   *
   * @return A hash value
   */
  public abstract int hashCode();

  /**
   * This method returns a <code>String</code> representation of this
   * <code>Principal</code>.
   *
   * @return This <code>Principal</code> represented as a <code>String</code>.
   */
  public abstract String toString();
}

==> gcc-java-4.0.3.tar.bz2: gcc-4.0.3/libjava/java/security/Principal.java <==
/* Principal.java -- A security entity
   Copyright (C) 1998, 2002, 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.security;

/**
 * This interface models an entity (such as a user or a certificate authority)
 * for the purposes of applying the Java security model.
 *
 * @author Aaron M. Renn (arenn@urbanophile.com)
 * @see X509Certificate
 * @since 1.1
 * @status updated to 1.4
 */
public interface Principal
{
  /**
   * This method tests another <code>Principal</code> object for equality
   * with this one.
   *
   * @param obj the Object to test for equality
   * @return true if the specified <code>Principal</code> is equal
   */
  boolean equals(Object obj);

  /**
   * This method returns a <code>String</code> representation of this
   * <code>Principal</code>.
   *
   * @return this <code>Principal</code> represented as a <code>String</code>
   */
  String toString();

  /**
   * This method returns a hash code value for this <code>Principal</code>.
   * Remember the contract of hashCode - two objects which compare as
   * equals() must have the same hashCode().
   *
   * @return a hash value
   */
  int hashCode();

  /**
   * This method returns a <code>String</code> that names this
   * <code>Principal</code>.
   *
   * @return the name of this <code>Principal</code>
   */
  String getName();
} // interface Principal
